==> webgui_7.9.33.orig.tar.gz: WebGUI/lib/WebGUI/i18n/German/Asset_MatrixListing.pm <==
package WebGUI::i18n::German::Asset_MatrixListing;
use utf8;
our $I18N = {
  'Approve this listing.' => {
    'lastUpdated' => '1246483933',
    'message' => 'Diese Liste freigeben'
  },
  'CATEGORY_NAME_loop' => {
    'lastUpdated' => '1250936499',
    'message' => 'Eine Schleife mit Attributen und Werten dazu wird für jede Kategorie in dieser Matrix erstellt.
Der Name der Schleife ist der Kategoriename, wobei Leerzeichen mit Bindestrichen ersetzt werden und \'_loop\' am Ende hinzugefügt wird.

Wenn Sie also eine Kategorie "Blumen und Pflanzen" hätten, wäre die Bezeichnung der Schleife
"blumen-und-pflanzen_loop".'
  },
  'Delete this listing.' => {
    'lastUpdated' => '1250936531',
    'message' => 'Diese Liste löschen.'
  },
  'Edit this listing.' => {
    'lastUpdated' => '1246484024',
    'message' => 'Diese Liste bearbeiten.'
  },
  'Send Creator a Message' => {
    'lastUpdated' => '1250936552',
    'message' => 'Mitteilung an den Autor dieser Liste.'
  },
  'approveOrDenyUrl' => {
    'lastUpdated' => '1250936611',
    'message' => 'Die URL zur Freigabe oder Ablehnung dieser Liste.'
  },
  'assetName' => {
    'lastUpdated' => '1246484578',
    'message' => 'Matrixliste'
  },
  'attribute_loop' => {
    'lastUpdated' => '1250936665',
    'message' => 'Eine Schleife mit den Attributen dieser Liste.'
  },
  'best label' => {
    'lastUpdated' => '1249633504',
    'message' => 'Am Besten'
  },
  'canApprove' => {
    'lastUpdated' => '1250936759',
    'message' => 'Ein Boolean-Wert, der angibt, ob der Benutzer diese Liste freigeben oder sperren kann.'
  },
  'canEdit' => {
    'lastUpdated' => '1250936778',
    'message' => 'Ein Boolean-Wert, der angibt, ob der Benutzer diese Liste bearbeiten kann.'
  },
  'categoryLabel' => {
    'lastUpdated' => '1246484153',
    'message' => 'Bezeichnung dieser Kategorie'
  },
  'clicks' => {
    'lastUpdated' => '1250936844',
    'message' => 'Die Gesamtanzahl von Klicks für diese Liste.'
  },
  'comment label' => {
    'lastUpdated' => '1244495860',
    'message' => 'Bemerkung'
  },
  'comments' => {
    'lastUpdated' => '1250936873',
    'message' => 'Listen-Kommentare'
  },
  'compares' => {
    'lastUpdated' => '1246483977',
    'message' => 'Anzahl der Vergleiche mit dieser Liste.'
  },
  'contact maintainer label' => {
    'lastUpdated' => '1246484176',
    'message' => 'Verwalter kontaktieren'
  },
  'count label' => {
    'lastUpdated' => '1236959869',
    'message' => 'Anzahl'
  },
  'description' => {
    'lastUpdated' => '1250936932',
    'message' => 'Listen-Beschreibung'
  },
  'description description' => {
    'lastUpdated' => '1250937079',
    'message' => 'Bitte geben Sie eine allgemeine Beschreibung für dieses Produkt ein. Spezifische Details können unten in den Formular-Feldern bewertet werden.'
  },
  'description label' => {
    'lastUpdated' => '1246484288',
    'message' => 'Beschreibung'
  },
  'detail template help title' => {
    'lastUpdated' => '1250937194',
    'message' => 'Variablen zur Matrix-Listen-Detail-Vorlage'
  },
  'edit label' => {
    'lastUpdated' => '1246484519',
    'message' => 'Bearbeiten'
  },
  'edit listing template help title' => {
    'lastUpdated' => '1250937284',
    'message' => 'Bearbeiten der Variablen zur Matrix-Listen-Detail-Vorlage'
  },
  'edit matrix listing title' => {
    'lastUpdated' => '1250932386',
    'message' => 'Bearbeiten/Hinzufügen einer Liste'
  },
  'editUrl' => {
    'lastUpdated' => '1250937338',
    'message' => 'Die URL zum Bearbeitungsbildschirm dieser Liste.'
  },
  'emailForm' => {
    'lastUpdated' => '1249633550',
    'message' => 'Ein Formular für Emails an den Listenverwalter.'
  },
  'emailSent' => {
    'lastUpdated' => '1250937402',
    'message' => 'Kondition, die angibt, ob eine Email versandt wurde oder nicht.'
  },
  'fieldType' => {
    'lastUpdated' => '1250937461',
    'message' => 'Typ dieses Attributs'
  },
  'form' => {
    'lastUpdated' => '1244495883',
    'message' => 'Das komplette Bearbeitungsformular'
  },
  'general comment label' => {
    'lastUpdated' => '1249634188',
    'message' => 'Allgemeine Beschreibung'
  },
  'isPending' => {
    'lastUpdated' => '1247904205',
    'message' => 'Status, der angibt, ob die Liste freigegeben wurde oder nicht.'
  },
  'label' => {
    'lastUpdated' => '1244495912',
    'message' => 'Das Label zu diesem Attribut'
  },
  'last updated label' => {
    'lastUpdated' => '1246484361',
    'message' => 'Zuletzt aktualisiert'
  },
  'lastUpdated_date' => {
    'lastUpdated' => '1247904098',
    'message' => 'Datum der letzten Aktualisierung dieser Liste.'
  },
  'lastUpdated_epoch' => {
    'lastUpdated' => '1247904140',
    'message' => 'Das Epoch-Datum (Unixtime) der letzen Aktualisierung dieser Liste.'
  },
  'maintainer description' => {
    'lastUpdated' => '1249634297',
    'message' => 'Wenn leer, wird hier der Name des Verwalters eingetragen. Der Listenverwalter kann diese Liste ändern, auch wenn er nicht zu der Gruppe zum hinzufügen/ändern der Listen gehört.'
  },
  'maintainer label' => {
    'lastUpdated' => '1246484306',
    'message' => 'Verwalter'
  },
  'manufacturer label' => {
    'lastUpdated' => '1246484318',
    'message' => 'Hersteller'
  },
  'manufacturerName description' => {
    'lastUpdated' => '1250939743',
    'message' => 'Der Name des Herstellers des Produkts oder des Dienstleisters für den angebotenen Dienst.'
  },
  'manufacturerName label' => {
    'lastUpdated' => '1250932325',
    'message' => 'Firma'
  },
  'manufacturerURL description' => {
    'lastUpdated' => '1250939816',
    'message' => 'Wenn der Hersteller eine Website hat, geben Sie bitte hier die komplette URL an.'
  },
  'manufacturerURL label' => {
    'lastUpdated' => '1250939837',
    'message' => 'Hersteller-URL'
  },
  'manufacturerUrl' => {
    'lastUpdated' => '1249634129',
    'message' => 'Die URL des Herstellers'
  },
  'manufacturerUrl_click' => {
    'lastUpdated' => '1249634168',
    'message' => 'Die URL des Hersteller, wenn Sie die Anzahl der Klicks zu dieser Liste registrieren möchten.'
  },
  'mean label' => {
    'lastUpdated' => '1250939972',
    'message' => 'Durchschnittswert'
  },
  'median label' => {
    'lastUpdated' => '1250939984',
    'message' => 'Mittelwert'
  },
  'message sent message' => {
    'lastUpdated' => '1249633573',
    'message' => 'Nachricht abgeschickt.'
  },
  'product name description' => {
    'lastUpdated' => '1250940023',
    'message' => 'Geben Sie den Namen des Produkts ein. Wenn es verschiedene Versionen geben sollte, verwenden Sie am Besten gleiche Bezeichnungen.'
  },
  'product name label' => {
    'lastUpdated' => '1250940044',
    'message' => 'Produktname'
  },
  'productName' => {
    'lastUpdated' => '1250940095',
    'message' => 'Name dieser Liste. Dieser entspricht dem Titel der Liste.'
  },
  'productURL description' => {
    'lastUpdated' => '1250940142',
    'message' => 'Wenn das Produkt eine eigene Website hat, tragen Sie die komplette URL dazu ein.'
  },
  'productURL label' => {
    'lastUpdated' => '1250940170',
    'message' => 'Produkt-URL'
  },
  'productUrl' => {
    'lastUpdated' => '1249633763',
    'message' => 'URL des Herstellers zu diesem Listeneintrag'
  },
  'productUrl_click' => {
    'lastUpdated' => '1249633849',
    'message' => 'URL zum Produkt, wenn Sie die Anzahl der Clicks für diese Liste registrieren möchten.'
  },
  'rate submit label' => {
    'lastUpdated' => '1249633777',
    'message' => 'Bewerten'
  },
  'ratings' => {
    'lastUpdated' => '1250940305',
    'message' => 'Übersicht der Bewertungen zu dieser Liste mit einem Formular zur Bewertung, falls ein Besucher das Produkt noch nicht bewertet hat.'
  },
  'report error label' => {
    'lastUpdated' => '1249633602',
    'message' => 'Fehler melden'
  },
  'request type label' => {
    'lastUpdated' => '1249633627',
    'message' => 'Art der Anfrage'
  },
  'respectable label' => {
    'lastUpdated' => '1249633657',
    'message' => 'Respektabel'
  },
  'screenshots' => {
    'lastUpdated' => '1250940397',
    'message' => 'Screenshots zu dieser Liste mit Hilfe des ukplayer.'
  },
  'screenshots description' => {
    'lastUpdated' => '1250940545',
    'message' => 'Laden Sie ein Bild zum Produkt oder einen Screenshot, falls es eine Software ist, hoch.'
  },
  'screenshots label' => {
    'lastUpdated' => '1247904482',
    'message' => 'Screenshots/Bilder'
  },
  'send button label' => {
    'lastUpdated' => '1244496069',
    'message' => 'Abschicken'
  },
  'show ratings' => {
    'lastUpdated' => '1246484472',
    'message' => 'Bewertungen anzeigen'
  },
  'template description' => {
    'lastUpdated' => '1249633951',
    'message' => 'Selektieren Sie eine Vorlage für die Standardansicht der Matrix.'
  },
  'template label' => {
    'lastUpdated' => '1250940624',
    'message' => 'Matrix-Listenvorlage'
  },
  'value' => {
    'lastUpdated' => '1244495944',
    'message' => 'Wert dieses Attributs'
  },
  'version' => {
    'lastUpdated' => '1244495959',
    'message' => 'Version dieser Liste'
  },
  'version description' => {
    'lastUpdated' => '1250940767',
    'message' => 'Geben Sie die Version/Edition/Modellnummer für das Produkt ein.'
  },
  'version label' => {
    'lastUpdated' => '1244496082',
    'message' => 'Version/Modell'
  },
  'views' => {
    'lastUpdated' => '1250940839',
    'message' => 'Anzahl der Betrachtungen dieser Liste'
  },
  'web site label' => {
    'lastUpdated' => '1246484507',
    'message' => 'Website'
  },
  'worst label' => {
    'lastUpdated' => '1250940901',
    'message' => 'Am Schlechtesten'
  },
  'your email label' => {
    'lastUpdated' => '1244496044',
    'message' => 'Ihre Emailadresse'
  }
}
;

1;

==> webgui_7.10.28.orig.tar.gz: WebGUI/lib/WebGUI/i18n/German/Asset_MatrixListing.pm <==
package WebGUI::i18n::German::Asset_MatrixListing;
use utf8;
our $I18N = {
  'Approve this listing.' => {
    'lastUpdated' => '1246483933',
    'message' => 'Diese Liste freigeben'
  },
  'CATEGORY_NAME_loop' => {
    'lastUpdated' => '1250936499',
    'message' => 'Eine Schleife mit Attributen und Werten dazu wird für jede Kategorie in dieser Matrix erstellt.
Der Name der Schleife ist der Kategoriename, wobei Leerzeichen mit Bindestrichen ersetzt werden und \'_loop\' am Ende hinzugefügt wird.

Wenn Sie also eine Kategorie "Blumen und Pflanzen" hätten, wäre die Bezeichnung der Schleife
"blumen-und-pflanzen_loop".'
  },
  'Delete this listing.' => {
    'lastUpdated' => '1250936531',
    'message' => 'Diese Liste löschen.'
  },
  'Edit this listing.' => {
    'lastUpdated' => '1246484024',
    'message' => 'Diese Liste bearbeiten.'
  },
  'Send Creator a Message' => {
    'lastUpdated' => '1250936552',
    'message' => 'Mitteilung an den Autor dieser Liste.'
  },
  'approveOrDenyUrl' => {
    'lastUpdated' => '1250936611',
    'message' => 'Die URL zur Freigabe oder Ablehnung dieser Liste.'
  },
  'assetName' => {
    'lastUpdated' => '1246484578',
    'message' => 'Matrixliste'
  },
  'attribute_loop' => {
    'lastUpdated' => '1250936665',
    'message' => 'Eine Schleife mit den Attributen dieser Liste.'
  },
  'best label' => {
    'lastUpdated' => '1249633504',
    'message' => 'Am Besten'
  },
  'canApprove' => {
    'lastUpdated' => '1250936759',
    'message' => 'Ein Boolean-Wert, der angibt, ob der Benutzer diese Liste freigeben oder sperren kann.'
  },
  'canEdit' => {
    'lastUpdated' => '1250936778',
    'message' => 'Ein Boolean-Wert, der angibt, ob der Benutzer diese Liste bearbeiten kann.'
  },
  'categoryLabel' => {
    'lastUpdated' => '1246484153',
    'message' => 'Bezeichnung dieser Kategorie'
  },
  'clicks' => {
    'lastUpdated' => '1250936844',
    'message' => 'Die Gesamtanzahl von Klicks für diese Liste.'
  },
  'comment label' => {
    'lastUpdated' => '1244495860',
    'message' => 'Bemerkung'
  },
  'comments' => {
    'lastUpdated' => '1250936873',
    'message' => 'Listen-Kommentare'
  },
  'compares' => {
    'lastUpdated' => '1246483977',
    'message' => 'Anzahl der Vergleiche mit dieser Liste.'
  },
  'contact maintainer label' => {
    'lastUpdated' => '1246484176',
    'message' => 'Verwalter kontaktieren'
  },
  'count label' => {
    'lastUpdated' => '1236959869',
    'message' => 'Anzahl'
  },
  'description' => {
    'lastUpdated' => '1250936932',
    'message' => 'Listen-Beschreibung'
  },
  'description description' => {
    'lastUpdated' => '1250937079',
    'message' => 'Bitte geben Sie eine allgemeine Beschreibung für dieses Produkt ein. Spezifische Details können unten in den Formular-Feldern bewertet werden.'
  },
  'description label' => {
    'lastUpdated' => '1246484288',
    'message' => 'Beschreibung'
  },
  'detail template help title' => {
    'lastUpdated' => '1315294606',
    'message' => 'Matrix, Variablen zur Matrix-Listen-Detail-Vorlage'
  },
  'edit label' => {
    'lastUpdated' => '1246484519',
    'message' => 'Bearbeiten'
  },
  'edit listing template help title' => {
    'lastUpdated' => '1315294654',
    'message' => 'Matrix, Bearbeiten der Variablen zur Matrix-Listen-Detail-Vorlage'
  },
  'edit matrix listing title' => {
    'lastUpdated' => '1250932386',
    'message' => 'Bearbeiten/Hinzufügen einer Liste'
  },
  'editUrl' => {
    'lastUpdated' => '1250937338',
    'message' => 'Die URL zum Bearbeitungsbildschirm dieser Liste.'
  },
  'emailForm' => {
    'lastUpdated' => '1249633550',
    'message' => 'Ein Formular für Emails an den Listenverwalter.'
  },
  'emailSent' => {
    'lastUpdated' => '1250937402',
    'message' => 'Kondition, die angibt, ob eine Email versandt wurde oder nicht.'
  },
  'fieldType' => {
    'lastUpdated' => '1250937461',
    'message' => 'Typ dieses Attributs'
  },
  'form' => {
    'lastUpdated' => '1244495883',
    'message' => 'Das komplette Bearbeitungsformular'
  },
  'general comment label' => {
    'lastUpdated' => '1249634188',
    'message' => 'Allgemeine Beschreibung'
  },
  'isPending' => {
    'lastUpdated' => '1247904205',
    'message' => 'Status, der angibt, ob die Liste freigegeben wurde oder nicht.'
  },
  'label' => {
    'lastUpdated' => '1244495912',
    'message' => 'Das Label zu diesem Attribut'
  },
  'last updated label' => {
    'lastUpdated' => '1246484361',
    'message' => 'Zuletzt aktualisiert'
  },
  'lastUpdated_date' => {
    'lastUpdated' => '1247904098',
    'message' => 'Datum der letzten Aktualisierung dieser Liste.'
  },
  'lastUpdated_epoch' => {
    'lastUpdated' => '1247904140',
    'message' => 'Das Epoch-Datum (Unixtime) der letzen Aktualisierung dieser Liste.'
  },
  'maintainer description' => {
    'lastUpdated' => '1249634297',
    'message' => 'Wenn leer, wird hier der Name des Verwalters eingetragen. Der Listenverwalter kann diese Liste ändern, auch wenn er nicht zu der Gruppe zum hinzufügen/ändern der Listen gehört.'
  },
  'maintainer label' => {
    'lastUpdated' => '1246484306',
    'message' => 'Verwalter'
  },
  'manufacturer label' => {
    'lastUpdated' => '1246484318',
    'message' => 'Hersteller'
  },
  'manufacturerName description' => {
    'lastUpdated' => '1250939743',
    'message' => 'Der Name des Herstellers des Produkts oder des Dienstleisters für den angebotenen Dienst.'
  },
  'manufacturerName label' => {
    'lastUpdated' => '1250932325',
    'message' => 'Firma'
  },
  'manufacturerURL description' => {
    'lastUpdated' => '1250939816',
    'message' => 'Wenn der Hersteller eine Website hat, geben Sie bitte hier die komplette URL an.'
  },
  'manufacturerURL label' => {
    'lastUpdated' => '1250939837',
    'message' => 'Hersteller-URL'
  },
  'manufacturerUrl' => {
    'lastUpdated' => '1249634129',
    'message' => 'Die URL des Herstellers'
  },
  'manufacturerUrl_click' => {
    'lastUpdated' => '1249634168',
    'message' => 'Die URL des Hersteller, wenn Sie die Anzahl der Klicks zu dieser Liste registrieren möchten.'
  },
  'mean label' => {
    'lastUpdated' => '1250939972',
    'message' => 'Durchschnittswert'
  },
  'median label' => {
    'lastUpdated' => '1250939984',
    'message' => 'Mittelwert'
  },
  'message sent message' => {
    'lastUpdated' => '1249633573',
    'message' => 'Nachricht abgeschickt.'
  },
  'product name description' => {
    'lastUpdated' => '1250940023',
    'message' => 'Geben Sie den Namen des Produkts ein. Wenn es verschiedene Versionen geben sollte, verwenden Sie am Besten gleiche Bezeichnungen.'
  },
  'product name label' => {
    'lastUpdated' => '1250940044',
    'message' => 'Produktname'
  },
  'productName' => {
    'lastUpdated' => '1250940095',
    'message' => 'Name dieser Liste. Dieser entspricht dem Titel der Liste.'
  },
  'productURL description' => {
    'lastUpdated' => '1250940142',
    'message' => 'Wenn das Produkt eine eigene Website hat, tragen Sie die komplette URL dazu ein.'
  },
  'productURL label' => {
    'lastUpdated' => '1250940170',
    'message' => 'Produkt-URL'
  },
  'productUrl' => {
    'lastUpdated' => '1249633763',
    'message' => 'URL des Herstellers zu diesem Listeneintrag'
  },
  'productUrl_click' => {
    'lastUpdated' => '1249633849',
    'message' => 'URL zum Produkt, wenn Sie die Anzahl der Clicks für diese Liste registrieren möchten.'
  },
  'rate submit label' => {
    'lastUpdated' => '1249633777',
    'message' => 'Bewerten'
  },
  'ratings' => {
    'lastUpdated' => '1250940305',
    'message' => 'Übersicht der Bewertungen zu dieser Liste mit einem Formular zur Bewertung, falls ein Besucher das Produkt noch nicht bewertet hat.'
  },
  'report error label' => {
    'lastUpdated' => '1249633602',
    'message' => 'Fehler melden'
  },
  'request type label' => {
    'lastUpdated' => '1249633627',
    'message' => 'Art der Anfrage'
  },
  'respectable label' => {
    'lastUpdated' => '1249633657',
    'message' => 'Respektabel'
  },
  'screenshots' => {
    'lastUpdated' => '1250940397',
    'message' => 'Screenshots zu dieser Liste mit Hilfe des ukplayer.'
  },
  'screenshots description' => {
    'lastUpdated' => '1250940545',
    'message' => 'Laden Sie ein Bild zum Produkt oder einen Screenshot, falls es eine Software ist, hoch.'
  },
  'screenshots label' => {
    'lastUpdated' => '1247904482',
    'message' => 'Screenshots/Bilder'
  },
  'send button label' => {
    'lastUpdated' => '1244496069',
    'message' => 'Abschicken'
  },
  'show ratings' => {
    'lastUpdated' => '1246484472',
    'message' => 'Bewertungen anzeigen'
  },
  'template description' => {
    'lastUpdated' => '1249633951',
    'message' => 'Selektieren Sie eine Vorlage für die Standardansicht der Matrix.'
  },
  'template label' => {
    'lastUpdated' => '1250940624',
    'message' => 'Matrix-Listenvorlage'
  },
  'value' => {
    'lastUpdated' => '1244495944',
    'message' => 'Wert dieses Attributs'
  },
  'version' => {
    'lastUpdated' => '1244495959',
    'message' => 'Version dieser Liste'
  },
  'version description' => {
    'lastUpdated' => '1250940767',
    'message' => 'Geben Sie die Version/Edition/Modellnummer für das Produkt ein.'
  },
  'version label' => {
    'lastUpdated' => '1244496082',
    'message' => 'Version/Modell'
  },
  'views' => {
    'lastUpdated' => '1250940839',
    'message' => 'Anzahl der Betrachtungen dieser Liste'
  },
  'web site label' => {
    'lastUpdated' => '1246484507',
    'message' => 'Website'
  },
  'worst label' => {
    'lastUpdated' => '1250940901',
    'message' => 'Am Schlechtesten'
  },
  'your email label' => {
    'lastUpdated' => '1244496044',
    'message' => 'Ihre Emailadresse'
  }
}
;

1;
